@@ -1,4 +1,4 @@
-from .vqa import VQA, VQA2, VQACP, VQACP2
+from .vqa import VQA, VQA2, VQACP, VQACP2, AdVQA
 from .coco import COCO
 from .clevr import CLEVR
 from .gqa import GQA
\ No newline at end of file
