@@ -104,7 +104,7 @@ class CLEVR(Dataset):
         target = torch.zeros(len(self.aid_to_ans))
         ans_id = self.ans_to_aid[q["answer"]]
 
-        im = Image.open(img_path)
+        im = Image.open(img_path).convert("RGB")
         if self.transform is not None:
             im = self.transform(im)
         item = {
